[![CircleCI](https://circleci.com/gh/maxalbert/tohu.svg?style=shield)](https://circleci.com/gh/maxalbert/tohu)

tohu: Create random data in a controllable way
==============================================

Prerequisites
-------------

- [pipenv](https://docs.pipenv.org/)
- [PostgreSQL](https://www.postgresql.org/) (for running the tests)


Quick start
-----------

To run the tests:
```
$ pipenv install --dev
$ pipenv shell
$ make test
```


Copyright
---------

See [LICENSE](./LICENSE)
